@@ -173,7 +173,7 @@ port_check_connect_backs(port_info_t *port)
 	/*
 	 * Some data came in while we were shutting down the port.
 	 * Just ignore it for now, when the port is opened back up we
-	 * wills tart the connections.
+	 * will start the connections.
 	 */
 	return 1;
     }
@@ -621,6 +621,12 @@ net_fd_write(port_info_t *port, net_info_t *netcon,
     /* Can't use buffer send operation here, multiple writers can send
        from the buffers. */
     reterr = gensio_write(netcon->net, &count, buf->buf + *pos, to_send, NULL);
+    if (reterr)
+	/*
+	 * Mark that we have written all the data so the check for more data
+	 * to send will not count this one.
+	 */
+	*pos = port->dev_to_net.cursize;
     if (reterr == GE_REMCLOSE) {
 	shutdown_one_netcon(netcon, "Remote closed");
 	return -1;
@@ -852,12 +858,20 @@ s2n_modemstate(net_info_t *netcon, struct gensio *io, unsigned int modemstate)
     netcon->modemstate_mask = modemstate;
 #ifdef GENSIO_ACONTROL_SER_SET_MODEMSTATE_MASK
     len = snprintf(s, sizeof(s), "%d", modemstate);
+    if (netcon->port->io)
+	/* Set the port side's state. */
+	gensio_acontrol(netcon->port->io, GENSIO_CONTROL_DEPTH_FIRST,
+			GENSIO_CONTROL_SET,
+			GENSIO_ACONTROL_SER_SET_MODEMSTATE_MASK, s, len,
+			NULL, NULL, NULL);
+    /* Send the response. */
     gensio_acontrol(netcon->net, GENSIO_CONTROL_DEPTH_FIRST,
 		    GENSIO_CONTROL_SET,
 		    GENSIO_ACONTROL_SER_SET_MODEMSTATE_MASK, s, len,
 		    NULL, NULL, NULL);
     len = snprintf(s, sizeof(s), "%d",
 		   port->last_modemstate & netcon->modemstate_mask);
+    /* Send the current modemstate. */
     gensio_control(netcon->net, GENSIO_CONTROL_DEPTH_FIRST,
 		   GENSIO_CONTROL_SET,
 		   GENSIO_CONTROL_SER_SEND_MODEMSTATE, s, &len);
@@ -880,15 +894,25 @@ s2n_linestate(net_info_t *netcon, struct gensio *io, unsigned int linestate)
     netcon->linestate_mask = linestate;
 #ifdef GENSIO_ACONTROL_SER_SET_LINESTATE_MASK
     len = snprintf(s, sizeof(s), "%d", linestate);
+    if (netcon->port->io)
+	/* Set the port side. */
+	gensio_acontrol(netcon->port->io, GENSIO_CONTROL_DEPTH_FIRST,
+			GENSIO_CONTROL_SET,
+			GENSIO_ACONTROL_SER_SET_LINESTATE_MASK, s, len,
+			NULL, NULL, NULL);
+    /* Send the response. */
     gensio_acontrol(netcon->net, GENSIO_CONTROL_DEPTH_FIRST,
 		    GENSIO_CONTROL_SET,
 		    GENSIO_ACONTROL_SER_SET_LINESTATE_MASK, s, len,
 		    NULL, NULL, NULL);
-    len = snprintf(s, sizeof(s), "%d",
-		   port->last_linestate & netcon->linestate_mask);
-    gensio_control(netcon->net, GENSIO_CONTROL_DEPTH_FIRST,
-		   GENSIO_CONTROL_SET,
-		   GENSIO_CONTROL_SER_SEND_LINESTATE, s, &len);
+    /* Send the current linestate. */
+    if (port->last_linestate & netcon->linestate_mask) {
+	len = snprintf(s, sizeof(s), "%d",
+		       port->last_linestate & netcon->linestate_mask);
+	gensio_control(netcon->net, GENSIO_CONTROL_DEPTH_FIRST,
+		       GENSIO_CONTROL_SET,
+		       GENSIO_CONTROL_SER_SEND_LINESTATE, s, &len);
+    }
 #else
     len = snprintf(s, sizeof(s), "%d",
 		   port->last_linestate & netcon->linestate_mask);
@@ -1119,10 +1143,9 @@ s2n_sync(net_info_t *netcon)
     if (!io)
 	return;
     if (port->telnet_brk_on_sync)
-	gensio_acontrol(io, GENSIO_CONTROL_DEPTH_FIRST,
-			GENSIO_CONTROL_SET,
-			GENSIO_CONTROL_SER_SEND_BREAK, "", 0,
-			NULL, NULL, NULL);
+	gensio_control(io, GENSIO_CONTROL_DEPTH_FIRST,
+		       GENSIO_CONTROL_SET,
+		       GENSIO_CONTROL_SER_SEND_BREAK, "", 0);
 }
 
 static void
@@ -1132,10 +1155,9 @@ s2n_break(net_info_t *netcon)
 
     if (!io)
 	return;
-    gensio_acontrol(io, GENSIO_CONTROL_DEPTH_FIRST,
-		    GENSIO_CONTROL_SET,
-		    GENSIO_CONTROL_SER_SEND_BREAK, "", 0,
-		    NULL, NULL, NULL);
+    gensio_control(io, GENSIO_CONTROL_DEPTH_FIRST,
+		   GENSIO_CONTROL_SET,
+		   GENSIO_CONTROL_SER_SEND_BREAK, "", 0);
 }
 
 #else
