@@ -27,6 +27,8 @@
 #ifndef LED_H
 #define LED_H
 
+#include "absout.h"
+
 struct led_driver_s;
 
 struct led_s
@@ -34,6 +36,7 @@ struct led_s
     struct led_s *next;
     char *name;
 
+    unsigned int refcount;
     struct led_driver_s *driver;
     void *drv_data;
 };
@@ -43,13 +46,14 @@ struct led_driver_s {
     const char *name;
 
     /* required: parse the parameters from config file */
-    int (*init)(struct led_s *led, const char * const *options, int lineno);
+    int (*init)(struct led_s *led, const char * const *options, int lineno,
+		struct absout *eout);
 
     /* optional, but required when drv_data is malloced in init */
     int (*free)(struct led_s *led);
 
     /* optional: called once during initialization, prepares the LED */
-    int (*configure)(void *drv_data, int lineno);
+    int (*configure)(void *drv_data, int lineno, struct absout *eout);
 
     /* required: called when data transfer should be signaled */
     int (*flash)(void *drv_data);
@@ -66,11 +70,14 @@ int led_driver_register(struct led_driver_s *led_driver);
 
 /* Handle an LED config line */
 int add_led(const char *name, const char *driverstr,
-	    const char * const *options, int lineno);
+	    const char * const *options, int lineno, struct absout *eout);
 
-/* Search for a LED by name */
+/* Search for a LED by name.  This will increment the refcount. */
 struct led_s *find_led(const char *name);
 
+/* Decrement the LED's refcount and free if it reaches 0. */
+void free_led(struct led_s *led);
+
 /* Free all registered LEDs in the system */
 void free_leds(void);
 
