@@ -26,17 +26,19 @@
 #ifndef PORT
 #define PORT
 
+#ifdef WIN32
+#include <ws2tcpip.h>
+#else
 #include <netdb.h>
-#include <sys/time.h>
-#include <sys/socket.h>
-#include "gbuf.h"
-#include "absout.h"
+#endif
+
 #include <gensio/gensio.h>
 
-#if (defined(gensio_version_major) && (gensio_version_major > 2 ||	\
-     (gensio_version_major == 2 && gensio_version_minor >= 2)))
-#define DO_MDNS
-#endif
+#include "gbuf.h"
+#include "absout.h"
+#include "mdns.h"
+#include "timeproc.h"
+#include "fileio.h"
 
 /* States for the net_to_dev_state and dev_to_net_state. */
 #define PORT_NOT_STARTED		0 /* The dataxfer_start_port failed. */
@@ -52,9 +54,9 @@
 typedef struct trace_info_s
 {
     bool hexdump;     /* output each block as a hexdump */
-    bool timestamp;   /* preceed each line with a timestamp */
+    bool timestamp;   /* precede each line with a timestamp */
     char *filename;   /* open file.  NULL if not used */
-    int  fd;          /* open file.  -1 if not used */
+    ftype *f;         /* open file.  NULL if not used */
 } trace_info_t;
 
 typedef struct port_info port_info_t;
@@ -91,6 +93,8 @@ struct net_info {
 					   seconds) before the timeout
 					   goes off. */
 
+    bool timeout_running;		/* Do we use the timer? */
+
     /*
      * Close the session when all the output has been written to the
      * network port.
@@ -211,6 +215,8 @@ struct port_info
     struct port_remaddr *remaddrs;	/* Remote addresses allowed. */
     struct port_remaddr *connbacks;	/* Connect back addresses */
     unsigned int num_waiting_connect_backs;
+    unsigned int connback_timeout;
+    bool connback_timeout_set;
 
     unsigned int max_connections;	/* Maximum number of connections
 					   we can accept at a time for this
@@ -357,23 +363,8 @@ struct port_info
     gensiods sendon_len;
 
 #ifdef DO_MDNS
-    /*
-     * mdns info
-     */
-    bool mdns;
-    bool do_mdns_sysattrs;
-    unsigned int mdns_port;
-    int mdns_interface;
-    int mdns_nettype;
-    char *mdns_name;
-    char *mdns_type;
-    char *mdns_domain;
-    char *mdns_host;
-    const char **mdns_txt;
-    gensiods mdns_txt_argc;
-    gensiods mdns_txt_args;
-    struct gensio_mdns_service *mdns_service;
-#endif /* DO_MDNS */
+    struct mdns_info mdns_info;
+#endif
 };
 
 /* In dataxfer.c */
@@ -416,10 +407,10 @@ void free_port(port_info_t *port);
 
 /* In ser2net_str.c */
 struct gbuf *process_str_to_buf(port_info_t *port, net_info_t *netcon,
-				const char *str);
+				const char *str, struct absout *eout);
 char *process_str_to_str(port_info_t *port, net_info_t *netcon,
-			 const char *str, struct timeval *tv,
-			 gensiods *lenrv, int isfilename);
+			 const char *str, timev *ts,
+			 gensiods *lenrv, int isfilename, struct absout *eout);
 gensiods net_raddr_str(struct gensio *io, char *buf, gensiods buflen);
 
 /* In rotator.c */
@@ -431,7 +422,7 @@ void header_trace(port_info_t *port, net_info_t *netcon);
 void footer_trace(port_info_t *port, char *type, const char *reason);
 void do_trace(port_info_t *port, trace_info_t *t, const unsigned char *buf,
 	      gensiods buf_len, const char *prefix);
-void setup_trace(port_info_t *port);
+void setup_trace(port_info_t *port, struct absout *eout);
 void shutdown_trace(port_info_t *port);
 
 /* In addsyattrs.c */
